import MouseWheel from "@better-scroll/mouse-wheel";

MouseWheel.prototype.wheelMoveHandler = function (delta) {
  var _this = this;
  var _a = this.mouseWheelOpt, throttleTime = _a.throttleTime, dampingFactor = _a.dampingFactor;
  if (throttleTime && this.wheelMoveTimer) {
    this.deltaCache.push(delta);
  }
  else {
    var cachedDelta = this.deltaCache.reduce(function (prev, current) {
      return {
        x: prev.x + current.x,
        y: prev.y + current.y,
      };
    }, { x: 0, y: 0 });
    this.cleanCache();
    var _b = this.scroll.scroller, scrollBehaviorX = _b.scrollBehaviorX, scrollBehaviorY = _b.scrollBehaviorY;
    scrollBehaviorX.setMovingDirection(-delta.directionX);
    scrollBehaviorY.setMovingDirection(-delta.directionY);
    scrollBehaviorX.setDirection(delta.x);
    scrollBehaviorY.setDirection(delta.y);
    // when out of boundary, perform a damping scroll
    var newX = scrollBehaviorX.performDampingAlgorithm(Math.round(delta.x) + cachedDelta.x, dampingFactor);
    var newY = scrollBehaviorY.performDampingAlgorithm(Math.round(delta.y) + cachedDelta.x, dampingFactor);
    if (!this.scroll.trigger(this.scroll.eventTypes.mousewheelMove, {
      x: newX,
      y: newY,
    })) {
      var easeTime = this.getEaseTime();
      if (newX !== this.scroll.x || newY !== this.scroll.y) {
        // 如果是苹果触摸板，在加速度为负的情况下，会造成直接瞬间回到0位，视觉效果太差
        if (Math.abs(this.scroll.y - newY) < 1) {
          if (this.scroll.y > newY) {
            newY = this.scroll.y - 1.01
          } else {
            newY = this.scroll.y + 1.01
          }
        }
        this.scroll.scrollTo(newX, newY, easeTime);
      }
    }
    if (throttleTime) {
      this.wheelMoveTimer = window.setTimeout(function () {
        _this.wheelMoveTimer = 0;
      }, throttleTime);
    }
  }
};

export default MouseWheel;