import {
  queryFriendDetail,
  queryGroupDetail,
  imGroupQueryDetail,
  queryGroupMemberList
} from "./api";
import groupLogo from "../images/group_logo.png";
import teacherLogo from "../images/teacher_logo.png";
import { ConversationType, MessageType } from "@rongcloud/engine"; //

const getInitData = async list => {
  try {
    const tempList = [];
    list.forEach(item => {
      tempList.push({
        id: item.targetId,
        type: item.conversationType
      });
    });
    const group = await imGroupQueryDetail(tempList);
    const tempGroup = group.data || [];

    const temp = [];
    list.forEach(item => {
      const tempItem = {};
      const findItem = tempGroup.find(item2 => item2.id === item.targetId);

      if (item == ConversationType.GROUP) {
        tempItem.memberCount = 0; // memberCount 为群成员数量
      }
      // console.log(findItem, "findItem items");
      if (findItem && findItem.id) {
        tempItem.name = findItem.name;
        tempItem.portraitUri =
          findItem.avatar ||
          (item.conversationType === 1 ? teacherLogo : groupLogo);
      } else {
        tempItem.name = "";
        tempItem.portraitUri =
          item.conversationType === 1 ? teacherLogo : groupLogo;
      }
      // console.log({ ...item, ...tempItem }, "tempItem");
      temp.push({ ...item, ...tempItem });
    });
    return temp;
  } catch (e) {
    //
    console.log(e, "e");
    return [];
  }
};

export const custom_service = {
  // 获取用户详情
  getUserProfile: async userId => {
    // 需要通过 userId 向应用服务器获取 user 信息，拼接成如下格式
    // 注意：userInfo 的 Key 不可修改
    console.log(userId, "userId");
    const userInfo = {
      id: userId,
      name: "用户姓名",
      portraitUri: "用户头像 URI"
    };
    try {
      const res = await queryFriendDetail({ userId });
      // console.log(res, "res");
      userInfo.name = res.data.friend.username;
      userInfo.portraitUri = res.data.friend.avatar || teacherLogo;
    } catch {
      //
    }
    return Promise.resolve(userInfo);
  },
  // 获取会话详情
  getConversationProfile: async conversations => {
    // SDK 返回 conversations 为会话列表，可根据返回的 conversations 向应用服务器请求会话详情信息。
    // 请根据具体 conversation 信息匹配 name、portraitUri 拼接到 converationInfo 信息中。
    // console.log(conversations, "conversations");
    const promises = [];

    const tempConversations = await getInitData(conversations);
    // console.log(conversations, tempConversations, "tempConversations");

    // conversations.forEach(conversation => {
    //   const converationInfo = {
    //     ...conversation,
    //     name: conversation.name || `会话名称`,
    //     portraitUri:
    //       conversation.portraitUri || conversation.conversationType === 1
    //         ? teacherLogo
    //         : groupLogo
    //   };
    //   if (conversation == ConversationType.GROUP) {
    //     converationInfo.memberCount = 0; // memberCount 为群成员数量
    //   }
    // 只需要传递 converationInfo 信息，整体返回的数据格式不可改变
    // promises.push(Promise.resolve(converationInfo));
    // });
    // 只需要传递 converationInfo 信息，整体返回的数据格式不可改变
    promises.push(...tempConversations);
    return Promise.all(promises);
  },

  // 获取群组详情
  getGroupMembers: async conversation => {
    // 通过 conversation 的 targetid 获取群组成员信息
    // groupMembers 为群组成员 list，需要构建成对象数组。
    // 特别注意：如果传递的群组成员信息不准确会影响 @ 信息的发送和群组成员昵称的展示
    try {
      const res = await queryGroupMemberList({
        imGroupId: conversation.targetId
      });
      const groupMembers = res.data.map(item => {
        return {
          id: item.userId,
          name: item.nickname,
          portraitUri: item.user.avatar || teacherLogo
        };
      });
      // console.log(groupMembers, "groupMembers");
      return Promise.resolve(groupMembers);
    } catch {
      //
      return Promise.resolve([]);
    }
  }
};
