/* eslint-disable no-empty */
import Cookies from 'js-cookie'
import {
  hasIndexErrData
} from '@/views/main/api'
import {
  permission
} from '@/utils/directivePage'
import {
  queryTenantInfoSumm
} from '@/views/productService/api'
import dayjs from 'dayjs'
import { getTenantId } from '@/utils/auth'
const state = {
  sidebar: {
    opened: Cookies.get('sidebarStatus') ? !!+Cookies.get('sidebarStatus') : true,
    withoutAnimation: false
  },
  device: 'desktop',
  status: {
    indexErrData: false,
    remindMatterData: false,
    musicPatrol: false,
    studentInfo: false,
    teacherInfo: false,
    attendanceServe: false,

  },
  tenantInfo: {
    serverName: null,
    studentNum: 0,
    studentUpLimit: 0,
    expiryDate: null,
    expiryDateEnd: null,
    validRemaining: 0, // 剩余有效期
    balance: 0
  },
  loadCount: 0,
  isLoading: false
}

const mutations = {
  SET_LOAD_STATUS: (state, flag) => {
    state.isLoading = flag
  },
  RESET_LOAD_COUNT: state => {
    state.loadCount = 0
  },
  SET_LOAD_COUNT: (state, count) => {
    // 判断是否已经到0了
    if(state.loadCount < 0) {
      state.loadCount = 0
    } else {
      state.loadCount += count
    }
  },
  TOGGLE_SIDEBAR: state => {
    // state.sidebar.opened = !state.sidebar.opened
    state.sidebar.opened = true;
    state.sidebar.withoutAnimation = false
    if (state.sidebar.opened) {
      Cookies.set('sidebarStatus', 1)
    } else {
      Cookies.set('sidebarStatus', 0)
    }
  },
  CLOSE_SIDEBAR: (state, withoutAnimation) => {
    Cookies.set('sidebarStatus', 0)
    state.sidebar.opened = false
    state.sidebar.withoutAnimation = withoutAnimation
  },
  TOGGLE_DEVICE: (state, device) => {
    state.device = device
  },
  COMMIT_DOT_STATUS: (state, status) => {
    const {
      musicPatrol,
      studentInfo,
      teacherInfo,
      attendanceServe
    } = status
    state.status = {
      ...status,
      indexErrData: musicPatrol || studentInfo || teacherInfo || attendanceServe
    }
    toggleDot(state.status)
  },
  TEANAT_SETTING: (state, status) => {
    const {
      expiryDateEnd,
      ...res
    } = status
    state.tenantInfo = {
      ...res,
      // expiryDate: expiryDate ? dayjs(expiryDate).format('YYYY-MM-DD') : null,
      expiryDateEnd: expiryDateEnd ? dayjs(expiryDateEnd).format('YYYY-MM-DD') : null
    }
  }
}

const toggleDot = status => {
  const {
    indexErrData,
    remindMatterData
  } = status
  const dotStatus = indexErrData || remindMatterData
  setTimeout(() => {
    // const el = document.querySelector('.menu-wrapper a[href="#/main/main"] span')
    const el = document.querySelector('.el-scrollbar__view a.indexlayout-top-menu-li[href="#/main"] span')
    if (el) {
      if (dotStatus) {
        el.classList.add('main-dot')
      } else {
        el.classList.remove('main-dot')
      }
    }
  }, 500);
}

const actions = {
  setLoadStatus({
    commit
  }, flag) {

    commit('SET_LOAD_STATUS', flag)
  },
  // setLoadStatus
  resetLoadCount({
    commit
  }) {
    commit('RESET_LOAD_COUNT')
  },
  setLoadCount({
    commit
  }, count) {
    commit('SET_LOAD_COUNT', count)
  },
  toggleSideBar({
    commit
  }) {
    commit('TOGGLE_SIDEBAR')
  },
  closeSideBar({
    commit
  }, {
    withoutAnimation
  }) {
    commit('CLOSE_SIDEBAR', withoutAnimation)
  },
  toggleDevice({
    commit
  }, device) {
    commit('TOGGLE_DEVICE', device)
  },

  async setDotStatus({
    commit
  }) {
    if (permission('hasIndexErrData')) {
      try {
        const res = await hasIndexErrData()
        commit('COMMIT_DOT_STATUS', res.data)
      } catch (error) {}
    }
  },
  async setServiceInfo({
    commit
  }) {
    if (permission('tenantInfo/queryTenantInfoSumm')) {
      try {
        // console.log(getTenantId(), 'getTenantId')
        if(getTenantId()) {
          const res = await queryTenantInfoSumm()
          commit('TEANAT_SETTING', res.data)
        }
      } catch (error) {}
    }
  },

}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
