// 设置系统主题和主题色
import store from '@/store'
import { showFullScreenLoading, tryHideFullScreenLoading } from './request-loading'
const version = require('element-ui/package.json').version // element-ui version from node_modules
const ORIGINAL_THEME = '#409EFF' // default color

let chalk = ''
// let theme = ''

// themeList: [{
//   selected: true,
//   name: '大雅绿（默认）',
//   color: '#14928a',
//   style: 'background-color: #14928a'
// }, {
//   selected: false,
//   name: '拂晓蓝',
//   color: '#1890ff',
//   style: 'background-color: #1890ff'
// }, {
//   selected: false,
//   name: '薄暮',
//   color: '#f5222d',
//   style: 'background-color: #f5222d'
// }, {
//   selected: false,
//   name: '火山',
//   color: '#fa541c',
//   style: 'background-color: #fa541c'
// }, {
//   selected: false,
//   name: '日暮',
//   color: '#faad14',
//   style: 'background-color: #faad14'
// }, {
//   selected: false,
//   name: '明青',
//   color: '#13c2c2',
//   style: 'background-color: #13c2c2'
// }, {
//   selected: false,
//   name: '极客蓝',
//   color: '#2f54eb',
//   style: 'background-color: #2f54eb'
// }, {
//   selected: false,
//   name: '酱紫',
//   color: '#722ed1',
//   style: 'background-color: #722ed1'
// }],


// 设置主题色
export const setTheme = async (params) => { // 是否显示加载样式
  const { themeColor, theme, isLoading, saveTheme = true } = params
  if(themeColor) {
    const oldVal = ORIGINAL_THEME
    if (typeof themeColor !== 'string') return
    const themeCluster = getThemeCluster(themeColor.replace('#', ''))
    const originalCluster = getThemeCluster(oldVal.replace('#', ''))

    if(isLoading) {
      showFullScreenLoading(store)
    }

    const getHandler = (variable, id) => {
      return () => {
        const originalCluster = getThemeCluster(ORIGINAL_THEME.replace('#', ''))
        const newStyle = updateStyle(chalk, originalCluster, themeCluster)

        let styleTag = document.getElementById(id)
        if (!styleTag) {
          styleTag = document.createElement('style')
          styleTag.setAttribute('id', id)
          document.head.appendChild(styleTag)
        }
        styleTag.innerText = newStyle
      }
    }

    if (!chalk) {
      const url = `https://unpkg.com/element-ui@${version}/lib/theme-chalk/index.css`
      await getCSSString(url, 'chalk')
    }

    const chalkHandler = getHandler('chalk', 'chalk-style')

    chalkHandler()

    const styles = [].slice.call(document.querySelectorAll('style'))
      .filter(style => {
        const text = style.innerText
        return new RegExp(oldVal, 'i').test(text) && !/Chalk Variables/.test(text)
      })
    styles.forEach(style => {
      const { innerText } = style
      if (typeof innerText !== 'string') return
      style.innerText = updateStyle(innerText, originalCluster, themeCluster)
    })

    // 修改其它不是组件里面的颜色
    const element = document.querySelector('html')
    element.style.setProperty('--color-primary', themeColor)
  }
  // 修改主题
  if(theme) {
    document.querySelector("#body").className = theme
  }

  if(saveTheme) {
    // 修改存的主题色
    let tenantConfig = sessionStorage.getItem('tenantConfig')
    tenantConfig = tenantConfig ? JSON.parse(tenantConfig) : {}
    if(themeColor) {
      tenantConfig.themeColor = themeColor
    }
    if(theme) {
      tenantConfig.theme = theme
    }
    sessionStorage.setItem('tenantConfig', JSON.stringify(tenantConfig))
  }
  if(isLoading) {
    tryHideFullScreenLoading(store)
  }
}

function updateStyle(style, oldCluster, newCluster) {
  let newStyle = style
  oldCluster.forEach((color, index) => {
    newStyle = newStyle.replace(new RegExp(color, 'ig'), newCluster[index])
  })
  return newStyle
}

function getCSSString(url, variable) {
  return new Promise(resolve => {
    const xhr = new XMLHttpRequest()
    xhr.onreadystatechange = () => {
      if (xhr.readyState === 4 && xhr.status === 200) {
        chalk = xhr.responseText.replace(/@font-face{[^}]+}/, '')
        resolve()
      }
    }
    xhr.open('GET', url)
    xhr.send()
  })
}

function getThemeCluster(theme) {
  const tintColor = (color, tint) => {
    let red = parseInt(color.slice(0, 2), 16)
    let green = parseInt(color.slice(2, 4), 16)
    let blue = parseInt(color.slice(4, 6), 16)

    if (tint === 0) { // when primary color is in its rgb space
      return [red, green, blue].join(',')
    } else {
      red += Math.round(tint * (255 - red))
      green += Math.round(tint * (255 - green))
      blue += Math.round(tint * (255 - blue))

      red = red.toString(16)
      green = green.toString(16)
      blue = blue.toString(16)

      return `#${red}${green}${blue}`
    }
  }

  const shadeColor = (color, shade) => {
    let red = parseInt(color.slice(0, 2), 16)
    let green = parseInt(color.slice(2, 4), 16)
    let blue = parseInt(color.slice(4, 6), 16)

    red = Math.round((1 - shade) * red)
    green = Math.round((1 - shade) * green)
    blue = Math.round((1 - shade) * blue)

    red = red.toString(16)
    green = green.toString(16)
    blue = blue.toString(16)

    return `#${red}${green}${blue}`
  }

  const clusters = [theme]
  for (let i = 0; i <= 9; i++) {
    clusters.push(tintColor(theme, Number((i / 10).toFixed(2))))
  }
  clusters.push(shadeColor(theme, 0.1))
  return clusters
}
